/**/

Call RxFuncAdd 'StockLoadFuncs', 'RXSTOCK', 'StockLoadFuncs'

Call StockLoadFuncs

call RxFuncAdd 'MathLoadFuncs', 'REXXMATH', 'MathLoadFuncs'
call MathLoadFuncs

call getexpdates

globals.interest = 0.05

if ARG() > 0 then do
	parse arg stock
	call StockSetStock(stock)
	call calc(stock)
end
else do
	v = StockWalkStocks(FIRST)
	do while v \= ''
		call calc(v)
		v = StockWalkStocks(NEXT)
	end
end

return

calc: procedure expose globals.

parse arg v

d = StockWalkDividend(FIRST)
i = 0
do while d \= ''
	parse var d dat amt
	if julian(dat) + 365 >= date('B') then do
		i = i + 1
		globals.div.i.date = dat
		globals.div.i.amount = amt
	end
	d = StockWalkDividend(NEXT)
end

globals.div.0 = i

opt = StockWalkOptions(FIRST)
printed = 0
do while opt \= ''
	parse var opt call ser month year last high low age
	if age < 100 then do
		if printed = 0 then do
			vol = volatility(v)
			say v 'volatility = 'format(vol * 100,4,2)'%'
			printed = 1
		end
		dd = dividend_discount(month, year + 1900)
		call examine ser, month, year+1900, last, vol, call, dd
	end
	opt = StockWalkOptions(NEXT)
end

return

dividend_discount: procedure expose globals.

parse arg xm, xy

dd = 0

do i = 1 to globals.div.0
	y = 1900 + left(globals.div.i.date,2)
	m = substr(globals.div.i.date,3,2)
	d = substr(globals.div.i.date,5,2)
	do j = y to y + 5
		jul = julian(d,m,j)
		if  jul > DATE('B') then do
			if julian(globals.friday.xy.xm, xm, xy) > jul then do
				time = (jul - date('B')) / 365.2425
				fact = exp(-globals.interest * time)
				dd = dd + globals.div.i.amount * fact
			end
			else
				leave
		end
	end
end

return dd

examine: procedure expose globals.

parse arg series, month, year, price, vol, call, dd

d = date('B')
xd = julian(globals.friday.year.month, month, year)

if xd < d then
	return

time = (xd - d) / 365.2425

dat = substr(DATE('S'), 3)
val = StockGetQuote(dat) - dd

res = blackscholes(val, series, time, vol)

parse var res cv pv

if call = 'C' then
	bsv = cv
else
	bsv = pv

say '   ' call series globals.mn.month year price format(bsv,4,2)

return

volatility:

parse value DATE('S') with 3 y 5 m 7 d

m = m - 3
if m < 1 then do
	m = m + 12
	y = y - 1
end

dat = y * 10000 + m * 100 + d
q = StockGetQuote(dat)
h = 0
l = 100000
i = 0
avg = 0
r = 'x 'q
do while r \= ''
	parse var r d q
	if q > h then
		h = q
	avg = avg + q
	if q < l & q > 0 then
		l = q
	i = i + 1
	r = StockWalkQuotes(NEXT)
end

avg = avg / i

return (h - l) / avg

blackscholes: procedure expose globals.

parse arg stkpr, xpr, time, vol

/* say stkpr xpr time interest vol */

l = log(stkpr / xpr)
n = (vol * sqrt(time))
rt = globals.interest * time
ert = exp(-rt)

d1 = (l + rt) / n + n / 2
d2 = d1 - n

BScall = stkpr * normal(d1) - xpr * normal(d2) * ert
BSput  = -stkpr * normal(-d1) + xpr * normal(-d2) * ert

return BScall BSput

normal2:

parse arg x

return exp(-0.5 * (x ** 2)) / sqrt(2 * 3.141592)

normal:

parse arg x 

if x = 0 then 
	z = 0
else do 	
	y = fabs(x) / 2
     	if y >= 3 then
		z = 1
	else do
		if y < 1 then do
			w = y ** 2
			z = ((((((((0.000124818987 * w ,
			-.001075204047) * w + .005198775019) * w ,
			-.019198292004) * w + .059054035642) * w ,
			-.151968751364) * w + .319152932694) * w ,
			-.531923007300) * w + .797884560593) * y * 2.0;
		end
		else do
			y = y - 2
			z = (((((((((((((-.000045255659 * y ,
			+.000152529290) * y - .000019538132) * y ,
			-.000676904986) * y + .001390604284) * y ,
			-.000794620820) * y - .002034254874) * y ,
			+.006549791214) * y - .010557625006) * y ,
			+.011630447319) * y - .009279453341) * y ,
			+.005353579108) * y - .002141268741) * y ,
			+.000535310849) * y + .999936657524;
		end
	end
end
if x > 0 then
	return (z + 1) / 2
return (1 - z) / 2

/* julian levert het aantal dagen sinds 1-1-00 */
	
julian: procedure

if ARG() = 1 then do
	parse arg y 3 m 5 d
	y = y + 1900
end
else
	parse arg d, m, y

if m < 3 then do
	m = m + 12
	y = y - 1
end
y = y - 1
m = m - 1

return 365 * y + y % 4 -  y % 100 + y % 400 + m * 31 - (4 * m + 23) % 10 + d - 1

getexpdates: procedure expose globals.

t.0 = 19; t.1 = 18; t.2 = 17; t.3 = 16; t.4 = 15; t.5 = 21; t.6 = 20

do y = 1995 to 2000
	do m = 1 to 12
		dow = julian(1,m,y) // 7
		globals.friday.y.m = t.dow
	end
end

globals.mn.1 = 'Jan'; globals.mn.2 = 'Feb'; globals.mn.3 = 'Mar'
globals.mn.4 = 'Apr'; globals.mn.5 = 'May'; globals.mn.6 = 'Jun'
globals.mn.7 = 'Jul'; globals.mn.8 = 'Aug'; globals.mn.9 = 'Sep'
globals.mn.10 = 'Oct'; globals.mn.11 = 'Nov'; globals.mn.12 = 'Dec'


return



