
				RXSTOCK.MAN



Korte handleiding voor het gebruik van de REXX interface op Frobozz Investor.

RxStock geeft de mogelijkheid om via Rexx programma's informatie uit de
Investor database te halen en informatie toe te voegen. Hiervoor is een
aantal functies beschikbaar. Deze handleiding beschrijft de syntax van
die functies.

/************************************************************************/
/*			StockLoadFuncs					*/
/************************************************************************/

Functie
	StockLoadFuncs

Parameters
	geen

Returns
	0

Beschrijving
	Laadt alle Rexx interface functies van RxStock. Opent en laadt de
	database.

Voorbeeld
	/* init RxStock */

	Call RxFuncAdd 'StockLoadFuncs', 'RXSTOCK', 'StockLoadFuncs'

	StockLoadFuncs()


/************************************************************************/
/*			StockSave					*/
/************************************************************************/
	
Functie
	StockSave

Parameters
	geen

Returns
	0

Beschrijving
	Bewaar wijzigingen aan database.

Voorbeeld
	/* verwijder Ahold uit de database */

	Call RxFuncAdd 'StockLoadFuncs', 'RXSTOCK', 'StockLoadFuncs'

	StockLoadFuncs()

	call StockDelStock 'Ahold'

	call StockSave

/************************************************************************/
/*			StockAddStock					*/
/************************************************************************/

Functie
	StockAddStock

Parameters
	fondsnaam

Returns
	0 indien fonds al bestaat
	1 indien fonds werd aangemaakt

Beschrijving
	Voegt een nieuw fonds toe. Het fonds wordt ook het actieve fonds.


/************************************************************************/
/*			StockSetStock					*/
/************************************************************************/

Functie
	StockSetStock

Parameters
	fondsnaam

Returns
	0 indien fonds niet bestaat
	1 indien ok

Beschrijving
	Maakt van een bestaand fonds het actieve fonds.

/************************************************************************/
/*			StockDelStock					*/
/************************************************************************/

Functie
	StockDelStock

Parameters
	fondsnaam

Returns
	0 indien fonds niet bestaat
	1 indien fonds werd verwijderd

Beschrijving
	Verwijdert een bestaand fonds. Hiermee gaan ook alle koersen en
	dividenden verloren. Dit heeft geen invloed op het actieve fonds,
	tenzij het actieve fonds wordt verwijderd. Dan is er geen actief
	fonds meer.

/************************************************************************/
/*			StockAddQuote					*/
/************************************************************************/

Functie
	StockAddQuote

Parameters
	datum
	koers

Returns
	0 indien geen actief fonds 
		 ongeldige datum
		 koers kleiner of gelijk aan 0
	1 indien koers werd gewijzigd of toegevoegd

Beschrijving
	Wijzigt een koers of voegt die toe aan het actieve fonds.
	De datum dient te worden gepresenteerd in het formaat JJMMDD.

/************************************************************************/
/*			StockGetQuote					*/
/************************************************************************/

Functie
	StockGetQuote

Parameters
	datum

Returns
	slotkoers op deze datum
	leeg indien geen koers aanwezig op gegeven datum

Beschrijving
	Geeft de slotkoers van een fonds op een gegeven datum.
	De datum dient te worden gepresenteerd in het formaat JJMMDD.
	Het is vervolgens mogelijk om de opvolgende koersen met 
	StockWalkQuotes('NEXT') op te halen (ook als lege koers teruggekeerd
	wordt)

/************************************************************************/
/*			StockDelQuote					*/
/************************************************************************/

Functie
	StockDelQuote

Parameters
	datum

Returns
	0 indien ongeldige datum of geen koers bekend op die datum
	1 indien koers werd verwijderd

Beschrijving
	Verwijdert een koers in het actieve fonds.

/************************************************************************/
/*			StockAddDividend				*/
/************************************************************************/

Functie
	StockAddDividend

Parameters
	datum
	koers

Returns
	0 indien geen actief fonds 
		 ongeldige datum
		 bedrag kleiner of gelijk aan 0
	1 indien dividend werd gewijzigd of toegevoegd

Beschrijving
	Wijzigt een dividend of voegt die toe aan het actieve fonds.
	De datum dient te worden gepresenteerd in het formaat JJMMDD.

/************************************************************************/
/*			StockDelDividend				*/
/************************************************************************/

Functie
	StockDelDividend

Parameters
	datum

Returns
	0 indien ongeldige datum of geen dividend bekend op die datum
	1 indien dividend werd verwijderd

Beschrijving
	Verwijdert een dividend notering in het actieve fonds.


/************************************************************************/
/*			StockAddPortfolio				*/
/************************************************************************/

Functie
	StockAddPortfolio

Parameters
	portefeuillenaam

Returns
	0 indien portefeuille al bestaat
	1 indien portefeuille werd aangemaakt

Beschrijving
	Maakt een nieuwe, lege portefeuille aan.

/************************************************************************/
/*			StockSetPortfolio				*/
/************************************************************************/

Functie
	StockSetPortfolio

Parameters
	portefeuillenaam

Returns
	0 indien portefeuille niet bestaat
	1 indien portefeuille bestaat

Beschrijving
	Maakt de gegeven portefeuille actief.

/************************************************************************/
/*			StockDelPortfolio				*/
/************************************************************************/

Functie
	StockDelPortfolio

Parameters
	portefeuillenaam

Returns
	0 indien portefeuille niet bestaat
	1 indien portefeuille verwijderd is

Beschrijving
	Verwijdert de opgegeven portefeuille uit de database, inclusief alle
	daaraan verbonden transacties. Indien de gegeven portfeuille de
	actieve portfeuille is, vervalt deze ook.


/************************************************************************/
/*			StockAddTransaction				*/
/************************************************************************/

Functie
	StockAddTransaction

Parameters
	fonds
	datum
	aantal
	koers	(optioneel)
	kosten	(optioneel)

Returns
	0 indien geen actieve portfeuille
		 datum ongeldig
		 fonds onbekend
	1 indien transactie is toegevoegd

Beschrijving
	Voegt een transactie toe aan de actieve portefeuille. Indien geen
	koers opgegeven wordt, wordt de slotkoers van de transactiedatum
	gebruikt. Indien geen kosten worden opgegeven, worden deze op 0
	gesteld. Deze functie heeft geen invloed op het actieve fonds.

/************************************************************************/
/*			StockDelTransaction				*/
/************************************************************************/

Functie
	StockDelTransaction

Parameters
	fonds
	datum

Returns
	0 indien geen actieve portfeuille
		 datum ongeldig
		 fonds onbekend
	1 indien transactie is verwijderd

Beschrijving
	Verwijdert een transactie uit de actieve portefeuille.


/************************************************************************/
/*			StockWalkStocks					*/
/************************************************************************/

Functie
	StockWalkStocks

Parameters
	mode 'FIRST' of 'NEXT' (1 resp 0 worden ook ondersteund)

Returns
	fondsnaam

Beschrijving
	Loopt langs alle aanwezige fondsen in de database en maakt deze een
	voor een actief. De naam van elk fonds wordt teruggekeerd.

/************************************************************************/
/*			StockWalkQuotes					*/
/************************************************************************/

Functie
	StockWalkQuotes

Parameters
	mode 'FIRST' of 'NEXT' (1 resp 0 worden ook ondersteund)

Returns
	datum koers

Beschrijving
	Loopt langs alle koersen in het actieve fonds en keert deze een voor
	een terug. Een lege terugkeerwaarde betekent het einde van de lijst.

/************************************************************************/
/*			StockWalkDividend				*/
/************************************************************************/

Functie
	StockWalkDividend

Parameters
	mode 'FIRST' of 'NEXT' (1 resp 0 worden ook ondersteund)

Returns
	datum bedrag

Beschrijving
	Loopt langs alle dividenden in het actieve fonds en keert deze een
	voor een terug. Een lege terugkeerwaarde betekent het einde van de 
	lijst.


/************************************************************************/
/*			StockWalkOptions				*/
/************************************************************************/

Functie
	StockWalkOptions

Parameters
	mode 'FIRST' of 'NEXT' (1 resp 0 worden ook ondersteund)

Returns
	C/P serie maand jaar laatst bid ask age

Beschrijving
	Loopt langs alle opties van het actieve fonds en keert deze een
	voor een terug. Een lege terugkeerwaarde betekent het einde van de 
	lijst. De laatste waarde is een ouderdomsindicatie. Niet alle
	optie koersen zijn recent, daarom is het aan te bevelen om alleen
	de koersen met een lage 'leeftijd' te gebruiken

Voorbeeld
	C 57.5 7 95 1.2 1.4 1.0 5


/************************************************************************/
/*			StockWalkPortfolios				*/
/************************************************************************/

Functie
	StockWalkPortfolios

Parameters
	mode 'FIRST' of 'NEXT' (1 resp 0 worden ook ondersteund)

Returns
	portefeuillenaam

Beschrijving
	Loopt langs alle aanwezige portefeuilles in de database en maakt 
	deze een voor een actief. De naam van elk portefeuille wordt 
	teruggekeerd. Een lege naam betekent het einde van de lijst.

/************************************************************************/
/*			StockWalkTransactions				*/
/************************************************************************/

Functie
	StockWalkTransactions

Parameters
	mode 'FIRST' of 'NEXT' (1 resp 0 worden ook ondersteund)

Returns
	fondsnaam datum aantal koers kosten

Beschrijving
	Loopt langs alle transacties in de actieve portefeuille en keert de
	inhoud hiervan een voor een terug. Een lege regel betekent het einde
	van de transacties.

/************************************************************************/
/*			StockQueryStockData				*/
/************************************************************************/

Functie
	StockQueryStockData

Parameters
	item

Returns
	waarde van gevraagde item

Beschrijving
	Met deze functie kan een aantal variabelen van een fonds worden
	opgevraagd. De volgende items zijn beschikbaar:
		currency	valuta van het fonds (leeg is default)
		type		fondscategorie
		interest	coupon rente


